@@ -1,5 +1,5 @@
 /*
-  Copyright 2008-2011 David Robillard <http://drobilla.net>
+  Copyright 2008-2014 David Robillard <http://drobilla.net>
 
   Permission to use, copy, modify, and/or distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
@@ -39,25 +39,23 @@ lilv_collection_new(ZixComparator cmp, ZixDestroyFunc destructor)
 }
 
 void
-lilv_collection_free(LilvCollection* coll)
+lilv_collection_free(LilvCollection* collection)
 {
-	if (coll)
-		zix_tree_free((ZixTree*)coll);
+	if (collection) {
+		zix_tree_free((ZixTree*)collection);
+	}
 }
 
 unsigned
-lilv_collection_size(const LilvCollection* coll)
+lilv_collection_size(const LilvCollection* collection)
 {
-	return (coll ? zix_tree_size((const ZixTree*)coll) : 0);
+	return (collection ? zix_tree_size((const ZixTree*)collection) : 0);
 }
 
 LilvIter*
 lilv_collection_begin(const LilvCollection* collection)
 {
-	if (collection) {
-		return (LilvIter*)zix_tree_begin((ZixTree*)collection);
-	}
-	return NULL;
+	return collection ? (LilvIter*)zix_tree_begin((ZixTree*)collection) : NULL;
 }
 
 void*
@@ -99,20 +97,18 @@ lilv_plugin_classes_new(void)
 
 /* URI based accessors (for collections of things with URIs) */
 
-LILV_API
-const LilvPluginClass*
-lilv_plugin_classes_get_by_uri(const LilvPluginClasses* coll,
+LILV_API const LilvPluginClass*
+lilv_plugin_classes_get_by_uri(const LilvPluginClasses* classes,
                                const LilvNode*          uri)
 {
 	return (LilvPluginClass*)lilv_collection_get_by_uri(
-		(const ZixTree*)coll, uri);
+		(const ZixTree*)classes, uri);
 }
 
-LILV_API
-const LilvUI*
-lilv_uis_get_by_uri(const LilvUIs* coll, const LilvNode* uri)
+LILV_API const LilvUI*
+lilv_uis_get_by_uri(const LilvUIs* uis, const LilvNode* uri)
 {
-	return (LilvUI*)lilv_collection_get_by_uri((const ZixTree*)coll, uri);
+	return (LilvUI*)lilv_collection_get_by_uri((const ZixTree*)uis, uri);
 }
 
 /* Plugins */
@@ -123,28 +119,28 @@ lilv_plugins_new(void)
 	return lilv_collection_new(lilv_header_compare_by_uri, NULL);
 }
 
-LILV_API
-const LilvPlugin*
-lilv_plugins_get_by_uri(const LilvPlugins* list, const LilvNode* uri)
+LILV_API const LilvPlugin*
+lilv_plugins_get_by_uri(const LilvPlugins* plugins, const LilvNode* uri)
 {
-	return (LilvPlugin*)lilv_collection_get_by_uri((const ZixTree*)list, uri);
+	return (LilvPlugin*)lilv_collection_get_by_uri(
+		(const ZixTree*)plugins, uri);
 }
 
 /* Nodes */
 
-LILV_API
-bool
-lilv_nodes_contains(const LilvNodes* list, const LilvNode* value)
+LILV_API bool
+lilv_nodes_contains(const LilvNodes* nodes, const LilvNode* value)
 {
-	LILV_FOREACH(nodes, i, list)
-		if (lilv_node_equals(lilv_nodes_get(list, i), value))
+	LILV_FOREACH(nodes, i, nodes) {
+		if (lilv_node_equals(lilv_nodes_get(nodes, i), value)) {
 			return true;
+		}
+	}
 
 	return false;
 }
 
-LILV_API
-LilvNodes*
+LILV_API LilvNodes*
 lilv_nodes_merge(const LilvNodes* a, const LilvNodes* b)
 {
 	LilvNodes* result = lilv_nodes_new();
@@ -201,32 +197,27 @@ LILV_COLLECTION_IMPL(lilv_uis, LilvUIs, LilvUI)
 LILV_COLLECTION_IMPL(lilv_nodes, LilvNodes, LilvNode)
 LILV_COLLECTION_IMPL(lilv_plugins, LilvPlugins, LilvPlugin)
 
-LILV_API
-void
+LILV_API void
 lilv_plugin_classes_free(LilvPluginClasses* collection) {
 	lilv_collection_free(collection);
 }
 
-LILV_API
-void
+LILV_API void
 lilv_scale_points_free(LilvScalePoints* collection) {
 	lilv_collection_free(collection);
 }
 
-LILV_API
-void
+LILV_API void
 lilv_uis_free(LilvUIs* collection) {
 	lilv_collection_free(collection);
 }
 
-LILV_API
-void
+LILV_API void
 lilv_nodes_free(LilvNodes* collection) {
 	lilv_collection_free(collection);
 }
 
-LILV_API
-LilvNode*
+LILV_API LilvNode*
 lilv_nodes_get_first(const LilvNodes* collection) {
 	return (LilvNode*)lilv_collection_get(collection,
 	                                      lilv_collection_begin(collection));
