@@ -39,8 +39,9 @@
 #    include <io.h>
 #    define F_OK 0
 #    define mkdir(path, flags) _mkdir(path)
+#    if defined(_MSC_VER) && _MSC_VER <= 1400
 /** Implement 'CreateSymbolicLink()' for MSVC 8 or earlier */
-BOOLEAN WINAPI
+extern "C" BOOLEAN WINAPI
 CreateSymbolicLink(LPCTSTR linkpath, LPCTSTR targetpath, DWORD flags)
 {
 	typedef BOOLEAN (WINAPI* PFUNC)(LPCTSTR, LPCTSTR, DWORD);
@@ -49,6 +50,7 @@ CreateSymbolicLink(LPCTSTR linkpath, LPCTSTR targetpath, DWORD flags)
 	                                  "CreateSymbolicLinkA");
 	return pfn ? pfn(linkpath, targetpath, flags) : 0;
 }
+#    endif
 #else
 #    include <dirent.h>
 #    include <limits.h>
@@ -86,8 +88,9 @@ lilv_strjoin(const char* first, ...)
 	va_start(args, first);
 	while (1) {
 		const char* const s = va_arg(args, const char *);
-		if (s == NULL)
+		if (s == NULL) {
 			break;
+		}
 
 		const size_t this_len   = strlen(s);
 		char*        new_result = (char*)realloc(result, len + this_len + 1);
@@ -269,7 +272,12 @@ lilv_dirname(const char* path)
 bool
 lilv_path_exists(const char* path, void* ignored)
 {
+#ifdef HAVE_LSTAT
+	struct stat st;
+	return !lstat(path, &st);
+#else
 	return !access(path, F_OK);
+#endif
 }
 
 char*
@@ -427,6 +435,10 @@ lilv_get_latest_copy(const char* path, const char* copy_path)
 char*
 lilv_realpath(const char* path)
 {
+	if (!path) {
+		return NULL;
+	}
+
 #if defined(_WIN32)
 	char* out = (char*)malloc(MAX_PATH);
 	GetFullPathName(path, MAX_PATH, out, NULL);
@@ -547,18 +559,9 @@ lilv_dir_for_each(const char* path,
 #else
 	DIR* dir = opendir(path);
 	if (dir) {
-		long name_max = pathconf(path, _PC_NAME_MAX);
-		if (name_max == -1) {
-			name_max = 255;   // Limit not defined, or error
-		}
-
-		const size_t   len    = offsetof(struct dirent, d_name) + name_max + 1;
-		struct dirent* entry = (struct dirent*)malloc(len);
-		struct dirent* result;
-		while (!readdir_r(dir, entry, &result) && result) {
+		for (struct dirent* entry; (entry = readdir(dir));) {
 			f(path, entry->d_name, data);
 		}
-		free(entry);
 		closedir(dir);
 	}
 #endif
