@@ -1,5 +1,5 @@
 /*
-  Copyright 2007-2015 David Robillard <http://drobilla.net>
+  Copyright 2007-2016 David Robillard <http://drobilla.net>
   Copyright 2008 Krzysztof Foltman
 
   Permission to use, copy, modify, and/or distribute this software for any
@@ -15,7 +15,8 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#define _POSIX_C_SOURCE 200112L /* for setenv */
+#define _POSIX_C_SOURCE 200809L /* for setenv */
+#define _XOPEN_SOURCE   600     /* for mkstemp */
 
 #include <assert.h>
 #include <ctype.h>
@@ -30,9 +31,11 @@
 
 #ifdef _WIN32
 #    include <direct.h>
+#    include <io.h>
 #    define mkdir(path, flags) _mkdir(path)
 #    define setenv(n, v, r) SetEnvironmentVariable((n), (v))
 #    define unsetenv(n) SetEnvironmentVariable((n), NULL)
+#    define mkstemp(pat) _mktemp(pat)
 #else
 #    include <dirent.h>
 #    include <unistd.h>
@@ -76,13 +79,13 @@ delete_bundle(void)
 static void
 init_tests(void)
 {
-	strncpy(bundle_dir_name, getenv("HOME"), 900);
-	strcat(bundle_dir_name, "/.lv2");
-	mkdir(bundle_dir_name, 0700);
-	strcat(bundle_dir_name, "/lilv-test.lv2");
-	sprintf(bundle_dir_uri, "file://%s/", bundle_dir_name);
-	sprintf(manifest_name, "%s/manifest.ttl", bundle_dir_name);
-	sprintf(content_name, "%s/plugin.ttl", bundle_dir_name);
+	snprintf(bundle_dir_name, TEST_PATH_MAX, "%s/.lv2/lilv-test.lv2",
+	         getenv("HOME"));
+	lilv_mkdir_p(bundle_dir_name);
+
+	snprintf(bundle_dir_uri, TEST_PATH_MAX, "file://%s/", bundle_dir_name);
+	snprintf(manifest_name, TEST_PATH_MAX, "%s/manifest.ttl", bundle_dir_name);
+	snprintf(content_name, TEST_PATH_MAX, "%s/plugin.ttl", bundle_dir_name);
 
 	delete_bundle();
 }
@@ -102,8 +105,9 @@ write_file(const char* name, const char* content)
 {
 	FILE* f = fopen(name, "w");
 	size_t len = strlen(content);
-	if (fwrite(content, 1, len, f) != len)
+	if (fwrite(content, 1, len, f) != len) {
 		fatal_error("Cannot write file %s\n", name);
+	}
 	fclose(f);
 }
 
@@ -117,8 +121,9 @@ init_world(void)
 static int
 load_all_bundles(void)
 {
-	if (!init_world())
+	if (!init_world()) {
 		return 0;
+	}
 	lilv_world_load_all(world);
 	return 1;
 }
@@ -126,8 +131,9 @@ load_all_bundles(void)
 static void
 create_bundle(const char* manifest, const char* content)
 {
-	if (mkdir(bundle_dir_name, 0700) && errno != EEXIST)
+	if (mkdir(bundle_dir_name, 0700) && errno != EEXIST) {
 		fatal_error("Cannot create directory %s\n", bundle_dir_name);
+	}
 	write_file(manifest_name, manifest);
 	write_file(content_name, content);
 }
@@ -142,8 +148,9 @@ start_bundle(const char* manifest, const char* content)
 static void
 unload_bundle(void)
 {
-	if (world)
+	if (world) {
 		lilv_world_free(world);
+	}
 	world = NULL;
 }
 
@@ -159,9 +166,9 @@ cleanup(void)
 #define TEST_ASSERT(check) do {\
 	test_count++;\
 	if (!(check)) {\
-		assert(false);\
 		error_count++;\
-		fprintf(stderr, "lilv_test.c:%d: error: %s\n", __LINE__, #check);\
+		fprintf(stderr, "lilv_test.c:%d: error: test `%s' failed\n", __LINE__, #check);\
+		abort();\
 	}\
 } while (0)
 
@@ -226,8 +233,9 @@ test_value(void)
 			"lv2:port [ "
 			"  a lv2:ControlPort ; a lv2:InputPort ; "
 			"  lv2:index 0 ; lv2:symbol \"foo\" ; lv2:name \"Foo\" ; "
-			"] ."))
+			"] .")) {
 		return 0;
+	}
 
 	init_uris();
 
@@ -252,6 +260,23 @@ test_value(void)
 	TEST_ASSERT(!strcmp(lilv_node_as_string(sval), "Foo"));
 	TEST_ASSERT(lilv_node_as_int(ival) == 42);
 	TEST_ASSERT(fabs(lilv_node_as_float(fval) - 1.6180) < FLT_EPSILON);
+	TEST_ASSERT(isnan(lilv_node_as_float(sval)));
+
+#if defined(__clang__)
+#    pragma clang diagnostic push
+#    pragma clang diagnostic ignored "-Wdeprecated-declarations"
+#elif __GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6)
+#    pragma GCC diagnostic push
+#    pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
+
+	TEST_ASSERT(!strcmp(lilv_uri_to_path("file:///foo"), "/foo"));
+
+#if defined(__clang__)
+#    pragma clang diagnostic pop
+#elif __GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6)
+#    pragma GCC diagnostic pop
+#endif
 
 	LilvNode* loc_abs  = lilv_new_file_uri(world, NULL, "/foo/bar");
 	LilvNode* loc_rel  = lilv_new_file_uri(world, NULL, "foo");
@@ -345,6 +370,29 @@ test_util(void)
 {
 	TEST_ASSERT(!lilv_realpath(NULL));
 
+	char a_path[16];
+	char b_path[16];
+	strncpy(a_path, "copy_a_XXXXXX", sizeof(a_path));
+	strncpy(b_path, "copy_b_XXXXXX",  sizeof(b_path));
+	mkstemp(a_path);
+	mkstemp(b_path);
+
+	FILE* fa = fopen(a_path, "w");
+	FILE* fb = fopen(b_path, "w");
+	fprintf(fa, "AA\n");
+	fprintf(fb, "AB\n");
+	fclose(fa);
+	fclose(fb);
+
+	TEST_ASSERT(lilv_copy_file("does/not/exist", "copy"));
+	TEST_ASSERT(lilv_copy_file(a_path, "not/a/dir/copy"));
+	TEST_ASSERT(!lilv_copy_file(a_path, "copy_c"));
+	TEST_ASSERT(!lilv_file_equals(a_path, b_path));
+	TEST_ASSERT(lilv_file_equals(a_path, a_path));
+	TEST_ASSERT(lilv_file_equals(a_path, "copy_c"));
+	TEST_ASSERT(!lilv_file_equals("does/not/exist", b_path));
+	TEST_ASSERT(!lilv_file_equals(a_path, "does/not/exist"));
+	TEST_ASSERT(!lilv_file_equals("does/not/exist", "/does/not/either"));
 	return 1;
 }
 
@@ -379,8 +427,9 @@ test_discovery(void)
 			PLUGIN_NAME("Test plugin") " ; "
 			LICENSE_GPL " ; "
 			"lv2:port [ a lv2:ControlPort ; a lv2:InputPort ;"
-			" lv2:index 0 ; lv2:symbol \"foo\" ; lv2:name \"bar\" ; ] ."))
+			" lv2:index 0 ; lv2:symbol \"foo\" ; lv2:name \"bar\" ; ] .")) {
 		return 0;
+	}
 
 	init_uris();
 
@@ -458,8 +507,9 @@ test_verify(void)
 			PLUGIN_NAME("Test plugin") " ; "
 			LICENSE_GPL " ; "
 			"lv2:port [ a lv2:ControlPort ; a lv2:InputPort ;"
-			" lv2:index 0 ; lv2:symbol \"foo\" ; lv2:name \"bar\" ] ."))
+			" lv2:index 0 ; lv2:symbol \"foo\" ; lv2:name \"bar\" ] .")) {
 		return 0;
+	}
 
 	init_uris();
 	const LilvPlugins* plugins = lilv_world_get_all_plugins(world);
@@ -478,8 +528,9 @@ test_no_verify(void)
 	if (!start_bundle(MANIFEST_PREFIXES
 			":plug a lv2:Plugin ; lv2:binary <foo" SHLIB_EXT "> ; rdfs:seeAlso <plugin.ttl> .\n",
 			BUNDLE_PREFIXES
-			":plug a lv2:Plugin . "))
+			":plug a lv2:Plugin . ")) {
 		return 0;
+	}
 
 	init_uris();
 	const LilvPlugins* plugins = lilv_world_get_all_plugins(world);
@@ -504,8 +555,9 @@ test_classes(void)
 			"lv2:port [ "
 			"  a lv2:ControlPort ; a lv2:InputPort ; "
 			"  lv2:index 0 ; lv2:symbol \"foo\" ; lv2:name \"Foo\" ; "
-			"] ."))
+			"] .")) {
 		return 0;
+	}
 
 	init_uris();
 	const LilvPluginClass*   plugin   = lilv_world_get_plugin_class(world);
@@ -568,8 +620,9 @@ test_plugin(void)
 			"  lv2:portProperty lv2:reportsLatency ; "
 			"  lv2:designation lv2:latency "
 			"] . \n"
-			":thing doap:name \"Something else\" .\n"))
+			":thing doap:name \"Something else\" .\n")) {
 		return 0;
+	}
 
 	init_uris();
 	const LilvPlugins* plugins = lilv_world_get_all_plugins(world);
@@ -801,8 +854,9 @@ test_project(void)
 			"  lv2:portProperty lv2:reportsLatency ; "
 			"  lv2:designation lv2:latency "
 			"] . \n"
-			":thing doap:name \"Something else\" .\n"))
+			":thing doap:name \"Something else\" .\n")) {
 		return 0;
+	}
 
 	init_uris();
 	const LilvPlugins* plugins = lilv_world_get_all_plugins(world);
@@ -850,8 +904,9 @@ test_no_author(void)
 			"  lv2:portProperty lv2:reportsLatency ; "
 			"  lv2:designation lv2:latency "
 			"] . \n"
-			":thing doap:name \"Something else\" .\n"))
+			":thing doap:name \"Something else\" .\n")) {
 		return 0;
+	}
 
 	init_uris();
 	const LilvPlugins* plugins = lilv_world_get_all_plugins(world);
@@ -899,8 +954,9 @@ test_project_no_author(void)
 			"  lv2:portProperty lv2:reportsLatency ; "
 			"  lv2:designation lv2:latency "
 			"] . \n"
-			":thing doap:name \"Something else\" .\n"))
+			":thing doap:name \"Something else\" .\n")) {
 		return 0;
+	}
 
 	init_uris();
 	const LilvPlugins* plugins = lilv_world_get_all_plugins(world);
@@ -950,8 +1006,9 @@ test_preset(void)
 			"] . \n"
 			"<http://example.org/preset> a pset:Preset ;"
 			"  lv2:appliesTo :plug ;"
-	                  "  rdfs:label \"some preset\" .\n"))
+	                  "  rdfs:label \"some preset\" .\n")) {
 		return 0;
+	}
 
 	init_uris();
 	const LilvPlugins* plugins = lilv_world_get_all_plugins(world);
@@ -997,8 +1054,9 @@ test_prototype(void)
 			"  lv2:portProperty lv2:reportsLatency ; "
 			"  lv2:designation lv2:latency "
 			"] . \n"
-			":plug doap:name \"Instance\" .\n"))
+			":plug doap:name \"Instance\" .\n")) {
 		return 0;
+	}
 
 	init_uris();
 	const LilvPlugins* plugins = lilv_world_get_all_plugins(world);
@@ -1055,8 +1113,9 @@ test_port(void)
 			"  a lv2:AudioPort ; a lv2:OutputPort ; "
 			"  lv2:index 3 ; lv2:symbol \"audio_out\" ; "
 			"  lv2:name \"Audio Output\" ; "
-			"] ."))
+			"] .")) {
 		return 0;
+	}
 
 	init_uris();
 	const LilvPlugins* plugins = lilv_world_get_all_plugins(world);
@@ -1337,8 +1396,9 @@ test_ui(void)
 			"  lv2ui:optionalFeature lv2ui:ext_presets . "
 			":ui2 a lv2ui:GtkUI ; lv2ui:binary <ui2" SHLIB_EXT "> . "
 			":ui3 a lv2ui:GtkUI ; lv2ui:binary <ui3" SHLIB_EXT "> . "
-			":ui4 a lv2ui:GtkUI ; lv2ui:binary <ui4" SHLIB_EXT "> . "))
+			":ui4 a lv2ui:GtkUI ; lv2ui:binary <ui4" SHLIB_EXT "> . ")) {
 		return 0;
+	}
 
 	init_uris();
 	const LilvPlugins* plugins = lilv_world_get_all_plugins(world);
@@ -1418,6 +1478,7 @@ test_ui(void)
 uint32_t atom_Float = 0;
 float    in         = 1.0;
 float    out        = 42.0;
+float    control    = 1234.0;
 
 static const void*
 get_port_value(const char* port_symbol,
@@ -1433,6 +1494,10 @@ get_port_value(const char* port_symbol,
 		*size = sizeof(float);
 		*type = atom_Float;
 		return &out;
+	} else if (!strcmp(port_symbol, "control")) {
+		*size = sizeof(float);
+		*type = atom_Float;
+		return &control;
 	} else {
 		fprintf(stderr, "error: get_port_value for nonexistent port `%s'\n",
 		        port_symbol);
@@ -1452,6 +1517,8 @@ set_port_value(const char*     port_symbol,
 		in = *(const float*)value;
 	} else if (!strcmp(port_symbol, "output")) {
 		out = *(const float*)value;
+	} else if (!strcmp(port_symbol, "control")) {
+		control = *(const float*)value;
 	} else {
 		fprintf(stderr, "error: set_port_value for nonexistent port `%s'\n",
 		        port_symbol);
@@ -1613,6 +1680,18 @@ test_state(void)
 		get_port_value, world, 0, NULL);
 	TEST_ASSERT(lilv_state_equals(state2, state4));
 
+	// Set some metadata properties
+	lilv_state_set_metadata(state, map.map(map.handle, LILV_NS_RDFS "comment"),
+	                        "This is a comment",
+	                        strlen("This is a comment") + 1,
+	                        map.map(map.handle, "http://lv2plug.in/ns/ext/atom#Literal"),
+	                        LV2_STATE_IS_POD);
+	lilv_state_set_metadata(state, map.map(map.handle, "http://example.org/metablob"),
+	                        "LIVEBEEF",
+	                        strlen("LIVEBEEF") + 1,
+	                        map.map(map.handle, "http://example.org/MetaBlob"),
+	                        0);
+
 	// Save state to a directory
 	int ret = lilv_state_save(world, &map, &unmap, state, NULL,
 	                          "state/state.lv2", "state.ttl");
@@ -1623,6 +1702,16 @@ test_state(void)
 	                                             "state/state.lv2/state.ttl");
 
 	TEST_ASSERT(lilv_state_equals(state, state5));  // Round trip accuracy
+	TEST_ASSERT(lilv_state_get_num_properties(state) == 8);
+
+	// Attempt to save state to nowhere (error)
+	ret = lilv_state_save(world, &map, &unmap, state, NULL, NULL, NULL);
+	TEST_ASSERT(ret);
+
+	// Save another state to the same directory (update manifest)
+	ret = lilv_state_save(world, &map, &unmap, state, NULL,
+	                      "state/state.lv2", "state2.ttl");
+	TEST_ASSERT(!ret);
 
 	// Save state with URI to a directory
 	const char* state_uri = "http://example.org/state";
@@ -1823,8 +1912,9 @@ test_bad_port_symbol(void)
 			"  a lv2:ControlPort ; a lv2:InputPort ; "
 			"  lv2:index 0 ; lv2:symbol \"0invalid\" ;"
 			"  lv2:name \"Invalid\" ; "
-			"] ."))
+			"] .")) {
 		return 0;
+	}
 
 	init_uris();
 
@@ -1854,8 +1944,9 @@ test_bad_port_index(void)
 			"  a lv2:ControlPort ; a lv2:InputPort ; "
 			"  lv2:index \"notaninteger\" ; lv2:symbol \"invalid\" ;"
 			"  lv2:name \"Invalid\" ; "
-			"] ."))
+			"] .")) {
 		return 0;
+	}
 
 	init_uris();
 
@@ -1893,6 +1984,7 @@ test_string(void)
 	TEST_ASSERT(!strcmp((s = lilv_path_join("/a/", "/b")), "/a/b")); free(s);
 	TEST_ASSERT(!strcmp((s = lilv_path_join("/a/", "b")), "/a/b")); free(s);
 	TEST_ASSERT(!strcmp((s = lilv_path_join("/a", NULL)), "/a/")); free(s);
+	TEST_ASSERT(!strcmp((s = lilv_path_join(NULL, "/b")), "/b")); free(s);
 
 #ifndef _WIN32
 	setenv("LILV_TEST_1", "test", 1);
@@ -1940,6 +2032,205 @@ test_world(void)
 
 /*****************************************************************************/
 
+static int
+test_reload_bundle(void)
+{
+	// Create a simple plugin bundle
+	create_bundle(MANIFEST_PREFIXES
+	              ":plug a lv2:Plugin ; lv2:binary <foo" SHLIB_EXT "> ; rdfs:seeAlso <plugin.ttl> .\n",
+	              BUNDLE_PREFIXES
+	              ":plug a lv2:Plugin ; "
+	              PLUGIN_NAME("First name") " .");
+
+	if (!init_world()) {
+		return 0;
+	}
+
+	init_uris();
+	lilv_world_load_specifications(world);
+
+	// Load bundle
+	LilvNode* bundle_uri = lilv_new_uri(world, bundle_dir_uri);
+	lilv_world_load_bundle(world, bundle_uri);
+
+	// Check that plugin is present
+	const LilvPlugins* plugins = lilv_world_get_all_plugins(world);
+	const LilvPlugin*  plug    = lilv_plugins_get_by_uri(plugins, plugin_uri_value);
+	TEST_ASSERT(plug);
+
+	// Check that plugin name is correct
+	LilvNode* name = lilv_plugin_get_name(plug);
+	TEST_ASSERT(!strcmp(lilv_node_as_string(name), "First name"));
+	lilv_node_free(name);
+
+	// Unload bundle from world and delete it
+	lilv_world_unload_bundle(world, bundle_uri);
+	delete_bundle();
+
+	// Create a new version of the same bundle, but with a different name
+	create_bundle(MANIFEST_PREFIXES
+	              ":plug a lv2:Plugin ; lv2:binary <foo" SHLIB_EXT "> ; rdfs:seeAlso <plugin.ttl> .\n",
+	              BUNDLE_PREFIXES
+	              ":plug a lv2:Plugin ; "
+	              PLUGIN_NAME("Second name") " .");
+
+	// Check that plugin is no longer in the world's plugin list
+	TEST_ASSERT(lilv_plugins_size(plugins) == 0);
+
+	// Load new bundle
+	lilv_world_load_bundle(world, bundle_uri);
+
+	// Check that plugin is present again and is the same LilvPlugin
+	const LilvPlugin* plug2 = lilv_plugins_get_by_uri(plugins, plugin_uri_value);
+	TEST_ASSERT(plug2);
+	TEST_ASSERT(plug2 == plug);
+
+	// Check that plugin now has new name
+	LilvNode* name2 = lilv_plugin_get_name(plug2);
+	TEST_ASSERT(name2);
+	TEST_ASSERT(!strcmp(lilv_node_as_string(name2), "Second name"));
+	lilv_node_free(name2);
+
+	// Load new bundle again (noop)
+	lilv_world_load_bundle(world, bundle_uri);
+
+	cleanup_uris();
+	lilv_node_free(bundle_uri);
+	lilv_world_free(world);
+	world = NULL;
+
+	return 1;
+}
+
+/*****************************************************************************/
+
+static int
+test_replace_version(void)
+{
+	if (!init_world()) {
+		return 0;
+	}
+
+	LilvNode* plug_uri         = lilv_new_uri(world, "http://example.org/versioned");
+	LilvNode* lv2_minorVersion = lilv_new_uri(world, LV2_CORE__minorVersion);
+	LilvNode* lv2_microVersion = lilv_new_uri(world, LV2_CORE__microVersion);
+	LilvNode* minor            = NULL;
+	LilvNode* micro            = NULL;
+
+	char* old_bundle_path = lilv_strjoin(LILV_TEST_DIR, "old_version.lv2/", 0);
+
+	// Load plugin from old bundle
+	LilvNode* old_bundle = lilv_new_file_uri(world, NULL, old_bundle_path);
+	lilv_world_load_bundle(world, old_bundle);
+	lilv_world_load_resource(world, plug_uri);
+
+	// Check version
+	const LilvPlugins* plugins  = lilv_world_get_all_plugins(world);
+	const LilvPlugin*  old_plug = lilv_plugins_get_by_uri(plugins, plug_uri);
+	TEST_ASSERT(old_plug);
+	minor = lilv_world_get(world, plug_uri, lv2_minorVersion, 0);
+	micro = lilv_world_get(world, plug_uri, lv2_microVersion, 0);
+	TEST_ASSERT(!strcmp(lilv_node_as_string(minor), "1"));
+	TEST_ASSERT(!strcmp(lilv_node_as_string(micro), "0"));
+	lilv_node_free(micro);
+	lilv_node_free(minor);
+
+	char* new_bundle_path = lilv_strjoin(LILV_TEST_DIR, "new_version.lv2/", 0);
+
+	// Load plugin from new bundle
+	LilvNode* new_bundle = lilv_new_file_uri(world, NULL, new_bundle_path);
+	lilv_world_load_bundle(world, new_bundle);
+	lilv_world_load_resource(world, plug_uri);
+
+	// Check that version in the world model has changed
+	plugins = lilv_world_get_all_plugins(world);
+	const LilvPlugin* new_plug = lilv_plugins_get_by_uri(plugins, plug_uri);
+	TEST_ASSERT(new_plug);
+	TEST_ASSERT(lilv_node_equals(lilv_plugin_get_bundle_uri(new_plug), new_bundle));
+	minor = lilv_world_get(world, plug_uri, lv2_minorVersion, 0);
+	micro = lilv_world_get(world, plug_uri, lv2_microVersion, 0);
+	TEST_ASSERT(!strcmp(lilv_node_as_string(minor), "2"));
+	TEST_ASSERT(!strcmp(lilv_node_as_string(micro), "1"));
+	lilv_node_free(micro);
+	lilv_node_free(minor);
+
+	// Try to load the old version again
+	lilv_world_load_bundle(world, old_bundle);
+	lilv_world_load_resource(world, plug_uri);
+
+	// Check that version in the world model has not changed
+	plugins = lilv_world_get_all_plugins(world);
+	new_plug = lilv_plugins_get_by_uri(plugins, plug_uri);
+	TEST_ASSERT(new_plug);
+	minor = lilv_world_get(world, plug_uri, lv2_minorVersion, 0);
+	micro = lilv_world_get(world, plug_uri, lv2_microVersion, 0);
+	TEST_ASSERT(!strcmp(lilv_node_as_string(minor), "2"));
+	TEST_ASSERT(!strcmp(lilv_node_as_string(micro), "1"));
+	lilv_node_free(micro);
+	lilv_node_free(minor);
+
+	lilv_node_free(new_bundle);
+	lilv_node_free(old_bundle);
+	free(new_bundle_path);
+	free(old_bundle_path);
+	lilv_node_free(plug_uri);
+	lilv_node_free(lv2_minorVersion);
+	lilv_node_free(lv2_microVersion);
+	return 1;
+}
+
+/*****************************************************************************/
+
+static int
+test_get_symbol(void)
+{
+	if (!start_bundle(
+		    MANIFEST_PREFIXES
+		    ":plug a lv2:Plugin ; lv2:symbol \"plugsym\" ; lv2:binary <foo" SHLIB_EXT "> ; rdfs:seeAlso <plugin.ttl> .\n",
+		    BUNDLE_PREFIXES PREFIX_LV2EV
+		    ":plug a lv2:Plugin ; "
+		    PLUGIN_NAME("Test plugin") " ; "
+		    "lv2:symbol \"plugsym\" .")) {
+		return 0;
+	}
+
+	init_uris();
+
+	LilvNode* plug_sym      = lilv_world_get_symbol(world, plugin_uri_value);
+	LilvNode* path          = lilv_new_uri(world, "http://example.org/foo");
+	LilvNode* path_sym      = lilv_world_get_symbol(world, path);
+	LilvNode* query         = lilv_new_uri(world, "http://example.org/foo?bar=baz");
+	LilvNode* query_sym     = lilv_world_get_symbol(world, query);
+	LilvNode* frag          = lilv_new_uri(world, "http://example.org/foo#bar");
+	LilvNode* frag_sym      = lilv_world_get_symbol(world, frag);
+	LilvNode* queryfrag     = lilv_new_uri(world, "http://example.org/foo?bar=baz#quux");
+	LilvNode* queryfrag_sym = lilv_world_get_symbol(world, queryfrag);
+	LilvNode* nonuri        = lilv_new_int(world, 42);
+
+	TEST_ASSERT(lilv_world_get_symbol(world, nonuri) == NULL);
+	TEST_ASSERT(!strcmp(lilv_node_as_string(plug_sym), "plugsym"));
+	TEST_ASSERT(!strcmp(lilv_node_as_string(path_sym), "foo"));
+	TEST_ASSERT(!strcmp(lilv_node_as_string(query_sym), "bar_baz"));
+	TEST_ASSERT(!strcmp(lilv_node_as_string(frag_sym), "bar"));
+	TEST_ASSERT(!strcmp(lilv_node_as_string(queryfrag_sym), "quux"));
+
+	lilv_node_free(nonuri);
+	lilv_node_free(queryfrag_sym);
+	lilv_node_free(queryfrag);
+	lilv_node_free(frag_sym);
+	lilv_node_free(frag);
+	lilv_node_free(query_sym);
+	lilv_node_free(query);
+	lilv_node_free(path_sym);
+	lilv_node_free(path);
+	lilv_node_free(plug_sym);
+	cleanup_uris();
+
+	return 1;
+}
+
+/*****************************************************************************/
+
 /* add tests here */
 static struct TestCase tests[] = {
 	TEST_CASE(util),
@@ -1963,6 +2254,9 @@ static struct TestCase tests[] = {
 	TEST_CASE(string),
 	TEST_CASE(world),
 	TEST_CASE(state),
+	TEST_CASE(reload_bundle),
+	TEST_CASE(replace_version),
+	TEST_CASE(get_symbol),
 	{ NULL, NULL }
 };
 
